pub fn cast<T: NumCast, U: NumCast>(n: T) -> GenericResult<U>Expand description
Cast from a typed scalar to another based on num_traits
pub fn cast<T: NumCast, U: NumCast>(n: T) -> GenericResult<U>Cast from a typed scalar to another based on num_traits