pub fn nbytes_across<T: PrimInt + NumCast>(start: T, end: T) -> GenericResult<T>Expand description
Get the required length of bytes from a Range, bits indices across the bytes.
pub fn nbytes_across<T: PrimInt + NumCast>(start: T, end: T) -> GenericResult<T>Get the required length of bytes from a Range, bits indices across the bytes.